@@ -2,13 +2,8 @@
 #' 
 #' @description  Creates a plot of series 13522 (NCPI), along with series 4466 (NCPI core)
 #' 
-#' @param start A \code{character}. The stating period of the series.
-#' @param ylim A \code{numeric vector}. Y axis limits.
-#' @param xlim  A \code{numeric vector}. x axis limits.
-#' 
 #' @return An image file is saved in the 'graphs' folder, under the BETS installation directory. 
-#' 
-#' @importFrom rootSolve multiroot
+#'
 #' @importFrom zoo as.Date
 #' 
 #' @importFrom grDevices dev.new dev.off  pdf  png
@@ -16,12 +11,14 @@
 #' @importFrom stats ts plot.ts
 #' @importFrom graphics axis text  points  mtext arrows
 #' @importFrom graphics  strwidth
+#' @author Talitha Speranza \email{talitha.speranza@fgv.br}
 
 
-draw.ipca = function(start = NULL, ylim = NULL, xlim = NULL){
+draw.ipca = function(){
   
   ipca = BETS.get(13522)
   core = BETS.get(4466)
+  start = c(2006,1)
   
   if(is.null(start)){
     
@@ -56,12 +53,12 @@ draw.ipca = function(start = NULL, ylim = NULL, xlim = NULL){
   core_acc = ts(core_acc, start = c(1996,12), frequency = 12)
   core = window(core_acc, start = start)
   
-  lims = chart.add_basic(ts = ipca, ylim = ylim, xlim = xlim, title = "National Consumer Price Index (IPCA)", subtitle = "Cumulative 12-Month Percentage", arr.pos = "h", leg.pos = "none")
+  lims = chart.add_basic(ts = ipca, title = "National Consumer Price Index (IPCA)", subtitle = "Cumulative 12-Month Percentage", arr.pos = "h", leg.pos = "none")
   chart.add_extra(core, ylim = lims[3:4], xlim = lims[1:2], leg.pos = "none")
   abline(a = 4.5, b = 0, lty = 3, lwd = 3, col = "darkgray")
   
   legend("topleft", c("IPCA", "Core"), lty=c(1,2), lwd=c(2.5,2.5),col=c("firebrick4", "firebrick3"), bty = "n", cex = 0.9)
-  text(lims[2] - strwidth("Target"), 4.1, "Target", cex = 0.9)
+  text(lims[2] - 3*strwidth("Target"), 4.1, "Target", cex = 0.9)
   
   chart.add_notes(list(ipca = ipca, core = core), names = c("IPCA","Core"), ylim = lims[3:4], xlim = lims[1:2])
 
